"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_general_1 = require("@energyweb/utils-general");
const Issuer_1 = require("./wrappedContracts/Issuer");
const Registry_1 = require("./wrappedContracts/Registry");
const const_1 = require("./const");
const Issuer_json_1 = __importDefault(require("../build/contracts/Issuer.json"));
const Registry_json_1 = __importDefault(require("../build/contracts/Registry.json"));
async function migrateIssuer(web3, deployKey, registryAddress) {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const accountDeployment = web3.eth.accounts.privateKeyToAccount(privateKeyDeployment).address;
    const issuerAddress = (await utils_general_1.deploy(web3, Issuer_json_1.default.bytecode, {
        privateKey: privateKeyDeployment
    })).contractAddress;
    const issuer = new Issuer_1.Issuer(web3, issuerAddress);
    await issuer.initialize(const_1.CertificateTopic.IREC, registryAddress, accountDeployment, {
        privateKey: privateKeyDeployment
    });
    const version = await issuer.version();
    console.log(`PublicIssuer ${version} created at ${issuerAddress}`);
    return issuer;
}
exports.migrateIssuer = migrateIssuer;
async function migrateRegistry(web3, deployKey) {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const registryAddress = (await utils_general_1.deploy(web3, Registry_json_1.default.bytecode, {
        privateKey: privateKeyDeployment
    })).contractAddress;
    const registry = new Registry_1.Registry(web3, registryAddress);
    await registry.initialize({ privateKey: privateKeyDeployment });
    console.log(`Registry created at ${registryAddress}`);
    return registry;
}
exports.migrateRegistry = migrateRegistry;
//# sourceMappingURL=migrate.js.map